@@ -40,7 +40,7 @@ inline bool PositionPairCompare(const PositionPair& p1, const PositionPair& p2){
   if (p1.begin != p2.begin)
     return (p1.begin < p2.begin);
   return (p1.end < p2.end);
-};
+}
 
 /**
  * Store arbitrary number of ranges: e.g. [chr1:1-100, chr2:2-300....]
@@ -176,6 +176,7 @@ class RangeCollection{
 
   void sortChrVector() {
     // dumpStringVector(chrVector);
+    if (chrVector.empty()) return;
     std::sort(chrVector.begin(), chrVector.end(), compareChromName);
     // dumpStringVector(chrVector);
   };
@@ -346,8 +347,10 @@ class RangeList{
         positionPair(NULL){
       chromSize = rc.getChromVector().size();
       inChromRegionSize = getRegions(chromIndex)? getRegions(chromIndex)->size() : 0;
-      chrom = &(rc.getChromVector()[chromIndex]);
-      positionPair = getRegions(chromIndex);
+      if (chromSize) {
+        chrom = &(rc.getChromVector()[chromIndex]);
+        positionPair = getRegions(chromIndex);
+      }
     };
     iterator& operator++(){
       this->inChromRangeIndex ++;
