@@ -28,6 +28,7 @@
 
 #include "bzlib_private.h"
 
+#define UNUSED(x) (void)(x)
 
 /*---------------------------------------------------*/
 /*--- Bit stream I/O                              ---*/
@@ -501,6 +502,7 @@ void sendMTFValues ( EState* s )
       }
      
       nBytes = s->numZ;
+      UNUSED(nBytes);
       for (i = 0; i < 16; i++)
          if (inUse16[i]) bsW(s,1,1); else bsW(s,1,0);
 
